repositories

package
v0.0.0-...-10473f5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2019 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AppStoreRssRepository

type AppStoreRssRepository struct {
	// contains filtered or unexported fields
}

AppStoreRssRepository is a repository.

func NewAppStoreRssRepository

func NewAppStoreRssRepository() *AppStoreRssRepository

NewAppStoreRssRepository is a method to create an instance of AppStoreRssRepository.

func (*AppStoreRssRepository) Get

func (r *AppStoreRssRepository) Get() ([]map[string]string, error)

Get is a method to get review data from iTunes Store Rss.

type Attachment

type Attachment struct {
	AuthorName string   `json:"author_name"`
	Text       string   `json:"text"`
	Fields     []Field  `json:"fields"`
	Color      string   `json:"color"`
	MrkdwnIn   []string `json:"mrkdwn_in"`
}

Attachment is data struct for creating the slack message.

type Field

type Field struct {
	Title string `json:"title"`
	Value string `json:"value"`
}

Field is data struct for creating the slack message.

type Message

type Message struct {
	Name        string       `json:"username"`
	IconEmoji   string       `json:"icon_emoji"`
	Channel     string       `json:"channel"`
	Text        string       `json:"text"`
	Attachments []Attachment `json:"attachments"`
}

Message is data struct for creating the slack message.

type SlackWebhookRepository

type SlackWebhookRepository struct {
	// contains filtered or unexported fields
}

SlackWebhookRepository is a repository for handling the slack webhook integration.

func NewSlackWebhookRepository

func NewSlackWebhookRepository() *SlackWebhookRepository

NewSlackWebhookRepository is a method to create an instance of SlackWebhookRepository.

func (*SlackWebhookRepository) Send

func (r *SlackWebhookRepository) Send(reviews []entities.Review) error

Send is a method to send reviews to the specified slack channel.

type UpdateLogRepository

type UpdateLogRepository struct {
	// contains filtered or unexported fields
}

UpdateLogRepository is repository for accessing to the updated log file.

func NewUpdateLogRepository

func NewUpdateLogRepository() *UpdateLogRepository

NewUpdateLogRepository is a method to create an instance of UpdateLogRepository.

func (*UpdateLogRepository) ReadLatestUpdatedDate

func (r *UpdateLogRepository) ReadLatestUpdatedDate() (string, error)

ReadLatestUpdatedDate is a method to get the latest review update date from file.

func (*UpdateLogRepository) WriteLatestUpdatedDate

func (r *UpdateLogRepository) WriteLatestUpdatedDate(lastUpdateDate string) error

WriteLatestUpdatedDate is a method to write the latest review update date to file.

Jump to